summaryrefslogtreecommitdiff
path: root/support-files
diff options
context:
space:
mode:
authorsasha@mysql.sashanet.com <>2002-02-16 11:32:06 -0700
committersasha@mysql.sashanet.com <>2002-02-16 11:32:06 -0700
commitbcd8cd137239923c8eb7f356cd4f4073a223aa81 (patch)
tree11aa4f519717228eb4e5fcb3392004bb25fa677b /support-files
parentad308746ea2a455bf90565a7c6c15f227a50e9e4 (diff)
downloadmariadb-git-bcd8cd137239923c8eb7f356cd4f4073a223aa81.tar.gz
updated build scripts for new Linux build
Diffstat (limited to 'support-files')
-rw-r--r--support-files/mysql.spec.sh23
1 files changed, 19 insertions, 4 deletions
diff --git a/support-files/mysql.spec.sh b/support-files/mysql.spec.sh
index fcc09aa8302..0a34817fa3b 100644
--- a/support-files/mysql.spec.sh
+++ b/support-files/mysql.spec.sh
@@ -186,26 +186,36 @@ sh -c "PATH=\"${MYSQL_BUILD_PATH:-/bin:/usr/bin}\" \
# Use the build root for temporary storage of the shared libraries.
+OTHER_LIBC_DIR=/usr/local/mysql-glibc
RBR=$RPM_BUILD_ROOT
MBD=$RPM_BUILD_DIR/mysql-%{mysql_version}
if test -z "$RBR" -o "$RBR" = "/"
then
- echo "RPM_BUILD_ROOT has stupid value"
+ echo "RPM_BUILD_ROOT has insecure value"
exit 1
fi
rm -rf $RBR
mkdir -p $RBR
-# Build the shared libraries and mysqld-max
+# We need to build shared libraries separate from mysqld-max because we
+# are using --with-other-libc
-BuildMySQL "--enable-shared --enable-thread-safe-client --with-berkeley-db --with-innodb --with-mysqld-ldflags='-all-static' --with-server-suffix='-Max'"
+BuildMySQL "--disable-shared --with-other-libc=$OTHER_LIBC_DIR --with-berkeley-db --with-innodb --with-mysqld-ldflags='-all-static' --with-server-suffix='-Max'"
# Save everything for debug
# tar cf $RBR/all.tar .
-# Save shared libraries and mysqld-max
+# Save mysqld-max
mv sql/mysqld sql/mysqld-max
nm --numeric-sort sql/mysqld-max > sql/mysqld-max.sym
+
+# Save manual to avoid rebuilding
+mv Docs/manual.ps Docs/manual.ps.save
+make distclean
+mv Docs/manual.ps.save Docs/manual.ps
+
+#now build and save shared libraries
+BuildMySQL "--enable-shared --enable-thread-safe-client --without-server "
(cd libmysql/.libs; tar cf $RBR/shared-libs.tar *.so*)
(cd libmysql_r/.libs; tar rf $RBR/shared-libs.tar *.so*)
@@ -220,6 +230,7 @@ automake
BuildMySQL "--disable-shared" \
"--with-mysqld-ldflags='-all-static'" \
"--with-client-ldflags='-all-static'" \
+ "--with-other-libc=$OTHER_LIBC_DIR" \
"--without-berkeley-db --without-innodb"
nm --numeric-sort sql/mysqld > sql/mysqld.sym
@@ -416,6 +427,10 @@ fi
%changelog
+* Fri Feb 15 2002 Sasha
+
+- changed build to use --with-other-libc
+
* Fri Apr 13 2001 Monty
- Added mysqld-max to the distribution